package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcBjsjMapper;
import com.ruoyi.zongzhi.domain.TcBjsj;
import com.ruoyi.zongzhi.service.ITcBjsjService;

/**
 * 本级上级网评指令比列 (月)Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@Service
public class TcBjsjServiceImpl implements ITcBjsjService 
{
    @Autowired
    private TcBjsjMapper tcBjsjMapper;

    /**
     * 查询本级上级网评指令比列 (月)
     * 
     * @param id 本级上级网评指令比列 (月)主键
     * @return 本级上级网评指令比列 (月)
     */
    @Override
    public TcBjsj selectTcBjsjById(Long id)
    {
        return tcBjsjMapper.selectTcBjsjById(id);
    }

    /**
     * 查询本级上级网评指令比列 (月)列表
     * 
     * @param tcBjsj 本级上级网评指令比列 (月)
     * @return 本级上级网评指令比列 (月)
     */
    @Override
    public List<TcBjsj> selectTcBjsjList(TcBjsj tcBjsj)
    {
        return tcBjsjMapper.selectTcBjsjList(tcBjsj);
    }

    /**
     * 新增本级上级网评指令比列 (月)
     * 
     * @param tcBjsj 本级上级网评指令比列 (月)
     * @return 结果
     */
    @Override
    public int insertTcBjsj(TcBjsj tcBjsj)
    {
        return tcBjsjMapper.insertTcBjsj(tcBjsj);
    }

    /**
     * 修改本级上级网评指令比列 (月)
     * 
     * @param tcBjsj 本级上级网评指令比列 (月)
     * @return 结果
     */
    @Override
    public int updateTcBjsj(TcBjsj tcBjsj)
    {
        return tcBjsjMapper.updateTcBjsj(tcBjsj);
    }

    /**
     * 批量删除本级上级网评指令比列 (月)
     * 
     * @param ids 需要删除的本级上级网评指令比列 (月)主键
     * @return 结果
     */
    @Override
    public int deleteTcBjsjByIds(Long[] ids)
    {
        return tcBjsjMapper.deleteTcBjsjByIds(ids);
    }

    /**
     * 删除本级上级网评指令比列 (月)信息
     * 
     * @param id 本级上级网评指令比列 (月)主键
     * @return 结果
     */
    @Override
    public int deleteTcBjsjById(Long id)
    {
        return tcBjsjMapper.deleteTcBjsjById(id);
    }
}
